@@ -1,5 +1,6 @@
 import os
 import re
+import rwlock
 from typing import List, Literal
 
 from loguru import logger
@@ -8,11 +9,11 @@ from platon_aide import Aide
 
 from platon_env.base.host import Host
 from platon_env.base.process import Process
-from platon_env.utils import join_path, do_once
-from utils import tar_files
+from platon_env.utils import join_path, tar_files
 
 
 class Node(Process):
+    _key_lock = rwlock.RWLock()
 
     def __init__(self,
                  host: Host,
@@ -79,23 +80,25 @@ class Node(Process):
         """
         return f"enode://{self.node_id}@{self.host.ip}:{self.p2p_port}"
 
-    def gql(self, scheme: Literal['ws', 'http'] = None):
+    def gql(self, scheme: Literal['ws', 'http'] = 'http'):
         """ 获取节点的graphql连接信息
         注意：当前仅支持http方式，其他scheme为超前设计
         """
-        match = re.search('--graphql', self.options)
+        if scheme == 'ws':
+            raise Exception('webSocket gql is currently not supported')
 
+        match = re.search('--graphql', self.options)
         if match:
             return f"{self.rpc(scheme)}/graphql/platon"
 
-        raise ValueError(f'The {scheme} graphql is not open.')
+        return None
 
-    def rpc(self, scheme: Literal['ws', 'http'] = None):
+    def rpc(self, scheme: Literal['ws', 'http'] = 'http'):
         """ 获取节点的rpc连接信息
         """
         options = self.options + ' '  # 在后面添加' '，避免出现miss match
-        ws_match = re.search('--wsport (.+?) ', options)
-        http_match = re.search('--rpcport (.+?) ', options)
+        ws_match = re.search('--ws.port (.+?) ', options)
+        http_match = re.search('--http.port (.+?) ', options)
 
         if (scheme == 'ws' or not scheme) and ws_match:
             if self.ssl:
@@ -160,15 +163,16 @@ class Node(Process):
             if not genesis_file:
                 raise ValueError('Private network needs genesis file.')
             self.host.connection.put(genesis_file, self.genesis_file)
+            self.init()
+
         if keystore:
             self.upload_keystore(keystore)
         if static_nodes:
             self.set_static_nodes(static_nodes)
+        self.host.ssh(f'mkdir -p {self.log_dir}')
 
         # 重置接口信息
         self.current_aide = None
-        # 启动节点
-        self.init()
         self.start(options)
 
         logger.info(f'Node {self} install success!')
@@ -189,12 +193,11 @@ class Node(Process):
     def init(self):
         """ 初始化节点
         """
-        self.host.ssh(f'mkdir -p {self.log_dir}')
         result = self.host.ssh(f'{self.platon} --datadir {self.data_dir} init {self.genesis_file}',
                                warn=False, strip=False)
         if result.failed or ('Fatal' in result.stderr or 'Error' in result.stderr):
             raise SSHException(result.stderr)
-        logger.info(f'Node {self} init success!')
+        logger.debug(f'Node {self} init success!')
 
     def start(self, options: str = ''):
         """ 使用supervisor启动节点
@@ -202,19 +205,19 @@ class Node(Process):
         self.options = options or self.options
         self.host.supervisor.add(self.name, self.supervisor_config)
         self.host.supervisor.start(self.name)
-        logger.info(f'Node {self} start success!')
+        logger.debug(f'Node {self} start success!')
 
     def restart(self):
         """ 使用supervisor重启节点
         """
         self.host.supervisor.restart(self.name)
-        logger.info(f'Node {self} restart success!')
+        logger.debug(f'Node {self} restart success!')
 
     def stop(self):
         """ 使用supervisor停止节点
         """
         self.host.supervisor.stop(self.name)
-        logger.info(f'Node {self} stop success!')
+        logger.debug(f'Node {self} stop success!')
 
     def upload_platon(self, platon_file):
         """ 使用缓存上传platon
@@ -227,11 +230,19 @@ class Node(Process):
         """ 使用缓存上传keystore，支持单个文件与目录
         """
         if os.path.isfile(keystore):
-            self.host.fast_put(keystore, self.keystore_dir)
+            self.host.ssh(f'mkdir -p {self.keystore_dir}')
+            self.host.connection.put(keystore, self.keystore_dir)
         elif os.path.isdir(keystore):
             tar_file = keystore + '.tar.gz'
-            do_once(tar_files, source=keystore, dest=tar_file)
+            # 添加写锁，压缩文件
+            Node._key_lock.writer_lock.acquire()
+            tar_files(keystore, tar_file)
+            Node._key_lock.writer_lock.release()
+            # 添加读锁，上传文件
+            Node._key_lock.reader_lock.acquire()
             tmp_file_path = self.host.fast_put(tar_file)
+            Node._key_lock.reader_lock.release()
+            # 解压钱包文件到节点
             self.host.ssh(f'mkdir -p {self.data_dir}')
             self.host.ssh(f'tar xzvf {tmp_file_path} -C {self.data_dir}')
         else:
